# pycamgeom
Package for projective camera and associated classes

Camera: projective camera class
Frame: represents a image and its pose in world coordinates
AABBtree: used to accelerate searches for world entities visible in camera image
